@@ -309,7 +309,7 @@ class Apps:
 
         if emails:
             params = self.saagie_api.check_alerting(emails, params, status_list)
-        elif type(emails) == list:
+        elif isinstance(emails, List):
             params["alerting"] = None
         else:
             previous_alerting = previous_app_version["alerting"]
@@ -387,16 +387,16 @@ class Apps:
             Otherwise False
         """
         list_exposed_port_field = ["basePathVariableName", "isRewriteUrl", "isAuthenticationRequired", "port", "name"]
-        if type(exposed_ports) != list:
+        if not isinstance(exposed_ports, List):
             return False
 
         if len(exposed_ports):
-            check_type = all([type(ep) == dict for ep in exposed_ports])
+            check_type = all(isinstance(ep, Dict) for ep in exposed_ports)
             if check_type:
-                check_port = all(["port" in ep.keys() for ep in exposed_ports])
+                check_port = all("port" in ep.keys() for ep in exposed_ports)
                 if check_port:
                     check_every_key = all(
-                        [all(elem in list_exposed_port_field for elem in ep.keys()) for ep in exposed_ports]
+                        all(elem in list_exposed_port_field for elem in ep.keys()) for ep in exposed_ports
                     )
                     if check_every_key:
                         return True
